@@ -28,7 +28,6 @@ import org.eclipse.core.runtime.Status;
 import org.eclipse.core.runtime.jobs.IJobChangeEvent;
 import org.eclipse.core.runtime.jobs.Job;
 import org.eclipse.core.runtime.jobs.JobChangeAdapter;
-import org.eclipse.linuxtools.internal.docker.ui.views.DockerExplorerView;
 import org.eclipse.swt.SWT;
 import org.eclipse.swt.SWTException;
 import org.eclipse.swt.widgets.Control;
@@ -37,7 +36,6 @@ import org.eclipse.swt.widgets.Event;
 import org.eclipse.swt.widgets.Menu;
 import org.eclipse.swt.widgets.Tree;
 import org.eclipse.swtbot.eclipse.finder.SWTWorkbenchBot;
-import org.eclipse.swtbot.eclipse.finder.waits.Conditions;
 import org.eclipse.swtbot.eclipse.finder.widgets.SWTBotView;
 import org.eclipse.swtbot.swt.finder.exceptions.WidgetNotFoundException;
 import org.eclipse.swtbot.swt.finder.finders.ContextMenuHelper;
@@ -75,17 +73,6 @@ public class SWTUtils {
 		return result.poll();
 	}
 
-	/**
-	 * Executes <strong>synchronously</strong> the given {@link Runnable} in the
-	 * default Display
-	 *
-	 * @param runnable
-	 *            the {@link Runnable} to execute
-	 */
-	public static void syncExec(final Runnable runnable) {
-		Display.getDefault().syncExec(runnable);
-	}
-
 	/**
 	 * Executes <strong>synchronously</strong> the given {@link Runnable} in the
 	 * default Display. The given {@link Runnable} is ran into a rapping
@@ -119,18 +106,6 @@ public class SWTUtils {
 		}
 	}
 
-	/**
-	 * Executes the given {@link Runnable} <strong>asynchronously</strong> in
-	 * the default {@link Display} and waits until all jobs are done before
-	 * completing.
-	 *
-	 * @param runnable
-	 * @throws InterruptedException
-	 */
-	public static void asyncExec(final Runnable runnable) {
-		asyncExec(runnable, true);
-	}
-
 	/**
 	 * Executes the given {@link Runnable} <strong>asynchronously</strong> in
 	 * the default {@link Display} and waits until all jobs are done before
@@ -178,18 +153,6 @@ public class SWTUtils {
 		}
 	}
 
-	/**
-	 * Waits for all {@link Job} to complete.
-	 *
-	 * @throws InterruptedException
-	 */
-	public static void waitForJobsToComplete(Object familly) {
-		// while (Job.getJobManager().find(familly).length > 0) {
-		// wait(1, TimeUnit.SECONDS);
-		// }
-		Conditions.waitForJobs(DockerExplorerView.class, "Docker Explorer View jobs");
-	}
-
 	/**
 	 * @param viewBot
 	 *            the {@link SWTBotView} containing the {@link Tree} to traverse
@@ -332,19 +295,6 @@ public class SWTUtils {
 		return parentTree.select(fullyQualifiedItems.toArray(new String[0]));
 	}
 
-	/**
-	 * Selects the given <code>treeItem</code> whose labels match the given
-	 * <code>items</code>.
-	 *
-	 * @param treeItem
-	 *            the parent tree item
-	 * @param matchItems
-	 *            the items to select
-	 */
-	public static void select(SWTBotTreeItem treeItem) {
-		treeItem.select();
-	}
-
 	/**
 	 * @param tree
 	 *            the root {@link SWTBotTree}
